<?php

/**
 * Administration form for selecting content types that should be associated
 * with panels sub-site slugs.
 *
 * @param array $form_state
 * @return string
 * 
 */
function panels_subsites_content_types_form(&$form_state) {

  // Finde all the node types and make them radio options frindly.
  $options = array();
  $types = node_get_types();
  foreach ($types as $key => $type) {
    $options[$key] = $type->name . '(' .t(check_plain($type->description)) . ')';
  }

  // Define fieldset for content types
  $form['content_types'] = array(
      '#type' => 'fieldset',
      '#title' => t('Content types'),
      '#description' => t('Select the content types that should be associated with slugs (also known as parent nodes).'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
  );

  $form['content_types']['panels_subsites_content_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types'),
    '#required' => TRUE,
    '#options' => $options,
    '#default_value' => variable_get('panels_subsites_content_types', array()),
  );

  // Define path prefixes for the selected content types
  $form['panels_subsites_prefix'] = array(
      '#type' => 'fieldset',
      '#title' => t('Path prefix'),
      '#tree' => TRUE,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
  );

  // Load defaults
  $defaults = variable_get('panels_subsites_prefix', array());

  // Run through content types 
  foreach ($types as $key => $type) {
    $form['panels_subsites_prefix'][$key] = array(
      '#type' => 'textfield',
      '#title' => $type->name,
      '#description' => t('Path prefix for content type "' . $key . '".'),
      '#default_value' => isset($defaults[$key]) ? $defaults[$key] : '',
    );
  }

  // FIXME: add support for auto update of pathauto paths (checkbox).

  return system_settings_form($form);
}