<?php

/**
 * Region slug editing form.
 */
function panels_subsites_slugs_form(&$form_state) {
  // Confirmation form for changing existing slugs. The storage array
  // is set by the submit handler, and as long as it is non-empty, we're
  // returned to the form.
  if (!empty($form_state['storage']['slug_changes'])) {
    $changes_text = array();
    foreach ($form_state['storage']['slug_changes'] as $change) {
      $changes_text[] = t('Change slug for %node from !old to !new', array(
        '%node' => $change['title'],
        '!old' => '<tt>' . check_plain($change['old_slug']) . '</tt>',
        '!new' => '<tt>' . check_plain($change['new_slug']) . '</tt>',
      ));
    }

    return confirm_form(array(), t('Please confirm these slug changes'), $_GET['q'], theme('item_list', $changes_text), t('Confirm'), t('Cancel'));
  }

  $form = array();
  $existing = array();

  $form['records']['#tree'] = TRUE;

  // Get selected content-types and group slugs base on type
  $types = array_filter(variable_get('panels_subsites_content_types', array()));

  foreach ($types as $type) {
    $node_type = node_get_types('type', $type);
    $slugs = panels_subsites_get_all_slugs_for_type($type);
    $form['records'][$type] = array(
      '#type' => 'fieldset',
      '#title' => check_plain($node_type->name),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );

    foreach ($slugs as $slug) {
      $form['records'][$type][$slug->nid] = array(
        '#type' => 'textfield',
        '#title' => $slug->title,
        '#default_value' => $slug->slug,
      );
      // Add the existing slugs to an array, so we'll be able to detect
      // overwriting in the validation.
      if (!empty($slug->slug)) {
        $existing[$slug->nid] = $slug->slug;
      }
    }
  }

  $form['existing_slugs'] = array(
    '#type' => 'value',
    '#value' => $existing,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save changes'),
  );
  
  drupal_set_message(t("Here you can edit the identifying part of the URL, called “slug”. Be aware that changing an existing slug will change the URLs too, resulting in dead links."), 'warning', FALSE);

  return $form;
}

/**
 * Submit handler for the slug editing form.
 */
function panels_subsites_slugs_form_submit($form, &$form_state) {
  // If the there's slug changes in the storage array, it means that
  // we've been through the confirmation form, and should now proceeed
  // to change the slugs in the database.
  if (isset($form_state['storage']['slug_changes'])) {
    foreach ($form_state['storage']['slug_changes'] as $change) {
      db_query("UPDATE {panels_subsites_slugs} SET slug = '%s', node_type = '%s' WHERE nid = %d;", $change['new_slug'], $change['type'], $change['nid']);
    }

    // Unset the storage, so we'll won't get the confirmation page again.
    unset($form_state['storage']);
  }
  $slug_changes = array();

  // Get selected content-types an group slugs base on type
  $types = array_filter(variable_get('panels_subsites_content_types', array()));

  // Save slugs for each type
  foreach ($types as $type) {
    if (isset ($form_state['values']['records'][$type])) {
      foreach ($form_state['values']['records'][$type] as $nid => $slug) {
        if (!empty($slug)) {
          if (isset($form_state['values']['existing_slugs'][$nid]) && $form_state['values']['existing_slugs'][$nid] != $slug) {
            // Existing slug is being changed, store the changes so we can
            // create a confirmation form with it.
            $slug_changes[$nid] = array(
              'nid' => $nid,
              'type' => $type,
              'title' => $form['records'][$nid]['#title'],
              'old_slug' => $form_state['values']['existing_slugs'][$nid],
              'new_slug' => panels_subsites_slugify($slug),
            );
          }
          else {
            // Create a new slug.
            if (!isset($form_state['values']['existing_slugs'][$nid])) {
              db_query("INSERT INTO {panels_subsites_slugs} (slug, nid, node_type) VALUES ('%s', %d, '%s')", panels_subsites_slugify($slug), $nid, $type);
            }
          }
        }
      }
    }
  }

  // Print status message
  if (empty($slug_changes)) {
    drupal_set_message('Slugs settings have been saved.');
  }
  
  $form_state['storage']['slug_changes'] = $slug_changes;
}
