<?php

/**
 * @file
 * This plug-in enables panels to load sub-site "parent" nodes based on the slug
 * from panels arugments (part of the url).
 * 
 */


/**
 * Implementation of hook_ctools_arguments().
 */
function panels_subsites_slug_ctools_arguments() {
  $args = array();

  $args['slug'] = array(
    'title' => t('Sub-sites slug'),
    'keyword' => 'node',
    'description' => t('Find node context based on the "slug" name for it.'),
    'context' => 'panels_subsites_slug_context',
  );

  return $args;
}

/**
 * Lookup an argument to see if it corresponds to a region.
 */
function panels_subsites_slug_context($arg = NULL, $conf = NULL, $empty = FALSE) {
  // If unset it wants a generic, unfilled context.
  if ($empty) {
    return ctools_context_create_empty('node');
  }

  // We can accept either a node object or a pure nid.
  if (is_object($arg)) {
    return ctools_context_create('node', $arg);
  }

  // Cast argument to an integer to see if it looks like a node ID.
  $num = intval($arg);
  if (is_numeric($num) && $num > 0) {
    $nid = $num;
  }
  elseif (strlen($arg) > 1) {
    // Try looking up the argument as a slug.
    $nid = db_result(db_query("
      SELECT nid FROM {panels_subsites_slugs} WHERE slug='%s'
    ", check_plain($arg)));
  }
  else {
    return FALSE;
  }

  // Check that it is a number that we found.
  if (!$nid || !is_numeric($nid)) {
    return FALSE;
  }

  // Load the related node.
  $node = node_load($nid);
  if (!$node) {
    return FALSE;
  }

  // Create the context.
  return ctools_context_create('node', $node);
}
