<?php
/**
 * @file
 * Provide the "parent" node related to a node as a Panels relation.
 */

/**
 * Implementation of hook_ctools_relationships().
 */
function panels_subsites_related_node_ctools_relationships() {

  $args = array();
  $args['related_node'] = array(
    'title' => t('Related node ("parent" node)'),
    'keyword' => 'related_node',
    'description' => t('Finds the related content type from a node context.'),
    'required context' => new ctools_context_required(t('Node'), 'node'),
    'context' => 'panels_subsites_related_node_context',
    'settings form' => 'panels_subsites_related_node_settings_form',
  );
  
  return $args;
}

/**
 * Return a new context based on an existing context.
 */
function panels_subsites_related_node_context($context = NULL, $conf = NULL) {
  // If unset it wants a generic, unfilled context, which is just NULL.
  if (empty($context->data)) {
    return ctools_context_create_empty('node');
  }

  // Place holder for the field.
  $ref_field = array();

  // Check forcefield settings (see settings form function for description).
  if (isset($conf['selected_field']) && strlen($conf['selected_field'])) {
    if (property_exists($context->data, $conf['selected_field'])) {
      $ref_field = $context->data->$conf['selected_field'];
    }
    else {
      watchdog(WATCHDOG_ERROR, t('Panels related node property do not exists (%field)', array('%field' => $conf['selected_field'])));
    }
  }

  // Get the ref field value from the current node.
  $ref_fields = panels_subsites_get_ref_fields($context->data->type);

  // There maybe more than one ref_field to check, so run through and fetch
  // the first one with content.
  if (empty ($ref_field)) {
    foreach ($ref_fields as $ref_field) {
      if ($ref_field) { // It maybe empty.
        $ref_field = $context->data->$ref_field;
        if (array_key_exists('nid', $ref_field[0]) && isset($ref_field[0]['nid'])) {
          break; // Found one.
        }
      }
    }
  }
  
  // If context was found load the node and create the context.
  if (isset($ref_field[0]) && $ref_field[0] > 0) {
    $node = node_load($ref_field[0]);
    if ($node) {
      return ctools_context_create('node', $node);
    }
  }
  return FALSE;
}

/**
 * Settings form for the relationship.
 */
function panels_subsites_related_node_settings_form($conf) {
  $form['forcefield'] = array(
    '#type' => 'fieldset',
    '#title' => t('Force-field'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );

  $form['selected_field'] = array(
    '#type' => 'textfield',
    '#title' => t('Field name'),
    '#default_value' => (isset($conf['selected_field'])) ? $conf['selected_field'] : '',
    '#description' => t('This field can be used to force an relationships. So the context represents a specifik reference field on the node (This only makes sens, with more than one "parent" node).'),
  );

  return $form;
}

